local core = CalendarExtras

local module = core:NewModule("Status Ingroup")

 --[[ -------- Locals ------- ]]--

local myName = UnitName("player")
local lastNumGroupMembers
local lastFrame -- Save the frame so we know what to update on events

 --[[ ----------------------- ]]--

local function InGroup(name)
	if name ~= myName or (name == myName and GetNumPartyMembers() > 0) then
		return UnitInRaid(name) or UnitInParty(name)
	end
	return nil
end

local function UpdateInviteListButtons(_, frame)
	if not frame then frame = lastFrame end
	if not frame then return end
	lastFrame = frame
	for _, button in ipairs(frame.buttons) do
		local inviteIndex = button.inviteIndex
		if inviteIndex then
			local buttonName = button:GetName()
			local name = CalendarEventGetInvite(inviteIndex)
			local inGroup = InGroup(name)
			local nameString, modIcon, partyIcon = _G[buttonName.."Name"], _G[buttonName.."ModIcon"], _G[buttonName.."PartyIcon"]
			if inGroup then
				partyIcon:Show()
				if modIcon:IsShown() then
					modIcon:SetPoint("LEFT", partyIcon, "RIGHT", -2, 0)
				else
					nameString:SetPoint("LEFT", partyIcon, "RIGHT", -2, 0)
				end
			else -- This next part is a bit redundant as the original Calendar***EventInviteListScrollFrame_Update already does the re-positioning, but I don't want to call core.UpdateOpenList() each time PARTY_MEMBERS_CHANGED fires
				partyIcon:Hide()
				if modIcon:IsShown() then
					modIcon:SetPoint("LEFT", modIcon:GetParent(), "LEFT", -2, 0)
				else
					nameString:SetPoint("LEFT")
				end
			end
		end
	end
end

function module:OnInitialize()
	core.RegisterCallback(self, "Post_Update", UpdateInviteListButtons)

	core.RegisterCallback(self, "CalendarShow", function()
		self:RegisterEvent("PARTY_MEMBERS_CHANGED", UpdateInviteListButtons)
	end)       
	core.RegisterCallback(self, "CalendarHide", function()
		self:UnregisterEvent("PARTY_MEMBERS_CHANGED")
	end)
end